@@ -63,30 +63,13 @@ use Getopt::Long;
 use Globus::GRAM::Error;
 use Globus::GRAM::JobDescription;
 
-my($manager_name, $argument_file, $command, $help);
+my($manager_name, $argument_file, $command) = (undef, undef, undef);
 
 GetOptions('manager-name|m=s' => \$manager_name,
            'argument-file|f=s' => \$argument_file,
-	   'command|c=s' => \$command,
-           "help|h" => \$help);
+	   'command|c=s' => \$command);
 $|=1;
 
-if ($help)
-{
-    my $managers;
-    print "USAGE: $0 -m MANAGER -f FILE -c COMMAND\n";
-    print "Installed managers:";
-    foreach (<$ENV{GLOBUS_LOCATION}/lib/perl/Globus/GRAM/JobManager/*.pm>)
-    {
-        my $manager = $_;
-        chomp($manager);
-        $manager =~ s|.*/||;
-        $manager =~ s|\.pm$||;
-        print " $manager";
-    }
-    print "\n";
-    exit(0);
-}
 if (!defined($manager_name))
 {
     &fail(Globus::GRAM::Error::BAD_SCRIPT_ARG_FILE);
@@ -184,19 +167,19 @@ sub run_command
     {
         if(defined $FILTER_COMMAND)
         {
-            my $commandName = join(" ", $job_description->executable,
+            local $commandName = join(" ", $job_description->executable,
                                            $job_description->arguments);
-            my @filterArgs = split(/\s+/, $FILTER_COMMAND);
+            local @filterArgs = split(/\s+/, $FILTER_COMMAND);
             if(-x $filterArgs[0])  # Make sure program is executable
             {
-                my $rVal = (system(@filterArgs, $commandName)) >> 8;
+                local $rVal = (system(@filterArgs, $commandName)) >> 8;
                 if($rVal != 0)  # The filter command returned an error, so deny.
                 {
                     &fail(Globus::GRAM::Error::AUTHORIZATION_DENIED_EXECUTABLE);
-                    goto FILTERED;
                 }
             }
         }
+        $manager->rewrite_urls();
     }
     $result = $manager->$cmd();
 
@@ -208,7 +191,6 @@ sub run_command
     {
         $manager->respond($result);
     }
-FILTERED:
     if ($command eq 'interactive')
     {
         print "\n";
